import { Server } from "socket.io";
import {TSocket} from "../../utilities/Types";
import {Character} from "@prisma/client";
import CharacterRepository from "../../repositories/CharacterRepository";
import {ZCharacterCreate} from "../../utilities/ZodTypes";

export default function (socket: TSocket, io: Server) {
    socket.on('character:create', async (data: any) => {
        // zod validate
        try {
            data = ZCharacterCreate.parse(data);

            const user_id = socket.user?.id as number;

            // Check if character name already exists
            const characterExists = await CharacterRepository.getByName(data.name);

            if (characterExists) {
                return socket.emit('notification', {message: 'Character name already exists'});
            }

            let characters: Character[] = await CharacterRepository.getByUserId(user_id) as Character[];

            if (characters.length >= 4) {
                return socket.emit('notification', {message: 'You can only have 4 characters'});
            }

            const character: Character = await CharacterRepository.create(user_id, data.name, 'player') as Character;
            characters = [...characters, character];

            socket.emit('character:create:success');
            socket.emit('character:list', characters);
        } catch (error: any) {
            return socket.emit('notification', {message: error.errors[0]?.message ?? 'Invalid data'});
        }
    });
}