import {Server} from "socket.io";
import {TSocket} from "../../utilities/Types";
import { Character, Zone } from '@prisma/client'
import CharacterRepository from "../../repositories/CharacterRepository";

type TypePayload = {
    character_id: number;
}

type TypeResponse = {
    zone: Zone;
    characters: Character[];
}

export default function (socket: TSocket, io: Server) {
    socket.on('character:delete', async (data: TypePayload, callback: (response: TypeResponse) => void) => {
        // zod validate
        try {
            await CharacterRepository.deleteByUserIdAndId(socket.user?.id as number, data.character_id as number);

            const user_id = socket.user?.id as number;
            const characters: Character[] = await CharacterRepository.getByUserId(user_id) as Character[];

            socket.emit('character:list', characters);
        } catch (error: any) {
            console.log(error);
            return socket.emit('notification', {message: 'Character delete failed. Please try again.'});
        }
    });
}